pub fn inspect_plugin_root(root: &Path) -> Result<PluginRootAuthoringState>Expand description
Inspects the current Host Catalog and Plugin Root without changing either.
pub fn inspect_plugin_root(root: &Path) -> Result<PluginRootAuthoringState>Inspects the current Host Catalog and Plugin Root without changing either.