pub fn resolve_runtime_app(
root: &Path,
host_build: &Path,
) -> Result<RuntimeAppResolution>Expand description
Resolves an external Plugin Root without allowing it to replace distribution authority.
pub fn resolve_runtime_app(
root: &Path,
host_build: &Path,
) -> Result<RuntimeAppResolution>Resolves an external Plugin Root without allowing it to replace distribution authority.